==> developer-center-api-3.3.5-ar-20181204.035749-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppSubpageLayoutDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;
import java.util.Collections;
import java.util.Map;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

/**
 * @ClassName: AppSubpageLayoutDto
 * @Description: TODO
 * @author: fxr
 * @date: 2018/8/1 下午2:59
 * @version: V1.0.0
 */
public class AppSubpageLayoutDto implements Serializable {

    private static final long serialVersionUID = 5563360378164302732L;

    private Long id;

    private Long appId;

    private JSONArray developSortJson = new JSONArray();                            // 开发者楼层排序json。

    private Map<Long, JSONObject> developDataShowJson = Collections.emptyMap();     // 开发者数据修改json

    private Short skinType;

    private Long skinId;

    public static final short Skin_Type_Old_Theme = 0;                   // 老皮肤

    public static final short Skin_Type_Floor_Skin = 1;                  // 新楼层皮肤

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Short getSkinType() {
        return skinType;
    }

    public void setSkinType(Short skinType) {
        this.skinType = skinType;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    /**
     * @return [{id:楼层Id,floorType:楼层类型,enable:是否展示}]
     */
    public JSONArray getDevelopSortJson() {
        return developSortJson;
    }

    public void setDevelopSortJson(JSONArray developSortJson) {
        this.developSortJson = developSortJson;
    }

    public Map<Long, JSONObject> getDevelopDataShowJson() {
        return developDataShowJson;
    }

    public void setDevelopDataShowJson(Map<Long, JSONObject> developDataShowJson) {
        this.developDataShowJson = developDataShowJson;
    }
}

==> developer-center-api-3.11.10-20251204.083454-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/AppSubpageLayoutDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;
import java.util.Collections;
import java.util.Map;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

/**
 * @ClassName: AppSubpageLayoutDto
 * @Description: TODO
 * @author: fxr
 * @date: 2018/8/1 下午2:59
 * @version: V1.0.0
 */
public class AppSubpageLayoutDto implements Serializable {//NOSONAR

    private static final long serialVersionUID = 5563360378164302732L;

    private Long id;

    private Long appId;

    private JSONArray developSortJson = new JSONArray();                            // 开发者楼层排序json。

    private Map<Long, JSONObject> developDataShowJson = Collections.emptyMap();     // 开发者数据修改json

    private Short skinType;

    private Long skinId;

    public static final short Skin_Type_Old_Theme = 0;                   // 老皮肤

    public static final short Skin_Type_Floor_Skin = 1;                  // 新楼层皮肤

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Short getSkinType() {
        return skinType;
    }

    public void setSkinType(Short skinType) {
        this.skinType = skinType;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    /**
     * @return [{id:楼层Id,floorType:楼层类型,enable:是否展示}]
     */
    public JSONArray getDevelopSortJson() {
        return developSortJson;
    }

    public void setDevelopSortJson(JSONArray developSortJson) {
        this.developSortJson = developSortJson;
    }

    public Map<Long, JSONObject> getDevelopDataShowJson() {
        return developDataShowJson;
    }

    public void setDevelopDataShowJson(Map<Long, JSONObject> developDataShowJson) {
        this.developDataShowJson = developDataShowJson;
    }
}
